@@ -7,9 +7,9 @@ from .builder import Builder
 from .compose import compose
 from .curry import curried
 from .error import EffectError, failwith
-from .fn import TailCall, recursive, recursive_async
+from .fn import TailCall, TailCallResult, tailrec, tailrec_async
 from .mailbox import AsyncReplyChannel, MailboxProcessor
-from .match import Matchable, Matcher, match
+from .match import Matchable, Matcher, Pattern, match
 from .misc import flip, fst, identity, snd
 from .option import Nothing, Nothing_, Option, Some
 from .pipe import pipe, pipe2, pipe3
@@ -36,14 +36,16 @@ __all__ = [
     "Ok",
     "Option",
     "option",
+    "Pattern",
     "pipe",
     "pipe2",
     "pipe3",
-    "recursive",
-    "recursive_async",
     "result",
     "Result",
     "snd",
     "Some",
     "TailCall",
+    "TailCallResult",
+    "tailrec",
+    "tailrec_async",
 ]
