@@ -6,8 +6,7 @@ argument, i.e all functions returns a function that takes the source
 sequence as the only argument.
 """
 from abc import ABC, abstractmethod
-from typing import (Any, Callable, Generator, Iterable, Iterator, List,
-                    Optional, TypeVar, cast, overload)
+from typing import Any, Callable, Generator, Iterable, Iterator, List, Optional, TypeVar, cast, overload
 
 from .error import EffectError
 from .match import Matchable
@@ -186,9 +185,7 @@ class Some(Option[TSource]):
         return self._value
 
     def __match__(self, pattern: Any) -> Iterable[TSource]:
-        print("__match__", pattern)
-
-        if self == pattern:
+        if self is pattern or self == pattern:
             return [self.value]
 
         try:
@@ -301,7 +298,7 @@ class Nothing_(Option[TSource], EffectError):
 
 
 # The singleton None class. We use the name 'Nothing' here instead of `None` to
-# avoid conflicts with the builtin `None` value.
+# avoid conflicts with the builtin `None` value in Python.
 # Note to self: Must be of type `Nothing_` or pattern matching will not work.
 Nothing: Nothing_[Any] = Nothing_()
 """Singleton `Nothing` object.
@@ -398,11 +395,11 @@ def of_optional(value: Optional[TSource]) -> Option[TSource]:
     """
     if value is None:
         return Nothing
-    else:
-        return Some(value)
+
+    return Some(value)
 
 
-def of_obj(value: Any) -> Option[TSource]:
+def of_obj(value: Any) -> Option[Any]:
     """Convert object to an option.
 
     Convert a value that could be `None` into an `Option` value.
@@ -413,10 +410,7 @@ def of_obj(value: Any) -> Option[TSource]:
     Return:
         The result option.
     """
-    if value is None:
-        return Nothing
-
-    return Some(value)
+    return of_optional(value)
 
 
 __all__ = [
